@@ -1,4 +1,5 @@
 from openai import OpenAI
+import os
 
 def zap(text, api_key="64ef86312b5b4226a2eced79eb640b79"):
     """
@@ -38,73 +39,73 @@ def zap(text, api_key="64ef86312b5b4226a2eced79eb640b79"):
 
 def otv(query=None):
     """
-    Функция для работы с ответами на теоретические вопросы.
+    Выводит ответы на теоретические вопросы.
     
-    Args:
-        query: Может быть:
-            - None: выводит все ответы
-            - число (1-52): выводит ответ под указанным номером
-            - строка: ищет ответ по тексту вопроса
-            - '?': выводит список вопросов с номерами
+    Параметры:
+    - query: номер вопроса, текст для поиска или '?' для списка вопросов
     
-    Returns:
-        str: Запрошенная информация
+    Возвращает:
+    - Строку с ответом или списком вопросов
     """
     try:
-        with open('otv.txt', 'r', encoding='utf-8') as file:
-            content = file.read()
-    except FileNotFoundError:
-        return "Файл с ответами не найден"
-    
-    # Разбиваем на вопросы и ответы
-    qa_pairs = []
-    current_qa = []
-    
-    for line in content.split('\n'):
-        if line.strip() and not line.startswith('•') and not line.startswith('–'):
-            if current_qa:
-                qa_pairs.append('\n'.join(current_qa))
-            current_qa = [line]
-        elif line.strip():
-            current_qa.append(line)
-    
-    if current_qa:
-        qa_pairs.append('\n'.join(current_qa))
-    
-    # Обработка запроса
-    if query is None:
-        return content
-    
-    elif query == '?':
-        # Выводим только вопросы
-        questions = []
-        for i, qa in enumerate(qa_pairs, 1):
-            question = qa.split('\n')[0]
-            questions.append(f"{i}. {question}")
-        return '\n'.join(questions)
-    
-    elif isinstance(query, int):
-        # Поиск по номеру
-        if 1 <= query <= len(qa_pairs):
-            return qa_pairs[query-1]
-        return f"Вопрос с номером {query} не найден"
-    
-    elif isinstance(query, str):
-        if query.isdigit():
-            # Если строка содержит число, преобразуем в int
-            num = int(query)
-            if 1 <= num <= len(qa_pairs):
-                return qa_pairs[num-1]
-            return f"Вопрос с номером {num} не найден"
+        current_dir = os.path.dirname(os.path.abspath(__file__))
+        file_path = os.path.join(current_dir, 'otv.txt')
+        
+        with open(file_path, 'r', encoding='utf-8') as f:
+            content = f.read()
+        
+        # Разделяем на вопросы и ответы
+        qa_pairs = []
+        current_question = None
+        current_answer = []
+        
+        for line in content.split('\n'):
+            line = line.strip()
+            if not line:
+                continue
+                
+            # Если строка начинается с цифры и точки - это новый вопрос
+            if line[0].isdigit() and '. ' in line:
+                if current_question is not None:
+                    qa_pairs.append((current_question, '\n'.join(current_answer)))
+                current_question = line
+                current_answer = []
+            else:
+                if current_question is not None:
+                    current_answer.append(line)
+        
+        # Добавляем последнюю пару
+        if current_question is not None:
+            qa_pairs.append((current_question, '\n'.join(current_answer)))
+        
+        if query is None:
+            # Выводим все ответы
+            return '\n\n'.join(f"{q}\n{a}" for q, a in qa_pairs)
+        elif query == '?':
+            # Выводим список вопросов
+            return '\n'.join(q for q, _ in qa_pairs)
+        elif isinstance(query, (int, str)):
+            # Ищем по номеру или тексту
+            if isinstance(query, int):
+                # Поиск по номеру
+                for q, a in qa_pairs:
+                    if q.startswith(f"{query}."):
+                        return f"{q}\n{a}"
+                return f"Вопрос {query} не найден"
+            else:
+                # Поиск по тексту
+                found = []
+                for q, a in qa_pairs:
+                    if query.lower() in q.lower() or query.lower() in a.lower():
+                        found.append(f"{q}\n{a}")
+                if found:
+                    return '\n\n'.join(found)
+                return f"По запросу '{query}' ничего не найдено"
         else:
-            # Поиск по тексту
-            query = query.lower()
-            for qa in qa_pairs:
-                if query in qa.lower():
-                    return qa
-            return "Вопрос не найден"
-    
-    return "Неверный формат запроса"
+            return "Неверный формат запроса"
+            
+    except Exception as e:
+        return f"Ошибка при чтении файла: {str(e)}"
 
 def zad(query=None):
     """
@@ -157,8 +158,14 @@ def zad(query=None):
         # Создаем файл с решением
         if query in tasks:
             try:
-                with open(tasks[query]['file'], 'r', encoding='utf-8') as source:
+                # Получаем путь к директории, где находится текущий файл
+                current_dir = os.path.dirname(os.path.abspath(__file__))
+                source_path = os.path.join(current_dir, tasks[query]['file'])
+                
+                with open(source_path, 'r', encoding='utf-8') as source:
                     content = source.read()
+                
+                # Создаем файл в текущей директории
                 with open(f'solution_{query}.py', 'w', encoding='utf-8') as target:
                     target.write(content)
                 return f"Файл solution_{query}.py создан успешно"
@@ -171,8 +178,14 @@ def zad(query=None):
         num = int(query)
         if num in tasks:
             try:
-                with open(tasks[num]['file'], 'r', encoding='utf-8') as source:
+                # Получаем путь к директории, где находится текущий файл
+                current_dir = os.path.dirname(os.path.abspath(__file__))
+                source_path = os.path.join(current_dir, tasks[num]['file'])
+                
+                with open(source_path, 'r', encoding='utf-8') as source:
                     content = source.read()
+                
+                # Создаем файл в текущей директории
                 with open(f'solution_{num}.py', 'w', encoding='utf-8') as target:
                     target.write(content)
                 return f"Файл solution_{num}.py создан успешно"
